==> nextcloud-24.0.9.tgz: nextcloud/apps/firstrunwizard/l10n/ka_GE.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "კოპირება ბუფერში",
    "Copied!" : "კოპირებულია!",
    "Not supported!" : "არაა მხარდაჭერილი",
    "Press ⌘-C to copy." : "კოპირებისთვის დააჭირეთ ⌘-C-ს.",
    "Press Ctrl-C to copy." : "კოპირებისთვის დააჭირეთ Ctrl-C-ს.",
    "First run wizard" : "პირველი გაშვების ოსტატი",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "დაამატეთ თქვენი პროფილის ინფორმაცია. დააყენეთ პროფილის ფოტო-სურათი და შეიყვანეთ თქვენი სრული სახელი, რათა ადვილად იყოთ ამოცნობილი სხვადასხვა ფუნქციებში.",
    "Add your profile information! Set a full name for easier recognition across all features." : "დაამატეთ თქვენი პროფილის ინფორმაცია! მიუთითეთ თქვენი სრული სახელი, რათა ადვილად იყოთ ამოცნობილი სხვადსახვა ფუნქციებში.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "დაამატეთ თქვენი პროფილის ინფორმაცია! დააყენეთ პროფილის ფოტო-სურათი, რათა ადვილად იყოთ ამოცნობილი სხვადასხვა ფუნქციებში.",
    "About" : "შესახებ",
    "Get the apps to sync your files" : "თქვენი ფაილების სინქრონიზაციისთვის მოიპოვეთ აპლიკაციები",
    "Desktop client" : "დესკტოპ-კლიენტი",
    "iOS app" : "iOS აპლიკაცია",
    "Connect your desktop apps to %s" : "დაუკავშირეთ თქვენი დესკტოპ აპლიკაციები %s-ს",
    "Connect your calendar" : "დააკავშირეთ თქვენი კალენდარი",
    "Connect your contacts" : "დააკავშირეთ თქვენი კონტაქტები",
    "Access files via WebDAV" : "დაუკავშირდით ფაილებს WebDAV–ით",
    "A safe home for all your data" : "უსაფრთხო სახლი მთელი თქვენი მონაცემებისათვის",
    "Server address" : "სერვერის მისამართი",
    "Copy link" : "ბმულის კოპირება"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-25.0.12.tgz: nextcloud/apps/firstrunwizard/l10n/ka_GE.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copied!" : "კოპირებულია!",
    "Not supported!" : "არაა მხარდაჭერილი",
    "Press ⌘-C to copy." : "კოპირებისთვის დააჭირეთ ⌘-C-ს.",
    "Press Ctrl-C to copy." : "კოპირებისთვის დააჭირეთ Ctrl-C-ს.",
    "First run wizard" : "პირველი გაშვების ოსტატი",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "დაამატეთ თქვენი პროფილის ინფორმაცია. დააყენეთ პროფილის ფოტო-სურათი და შეიყვანეთ თქვენი სრული სახელი, რათა ადვილად იყოთ ამოცნობილი სხვადასხვა ფუნქციებში.",
    "Add your profile information! Set a full name for easier recognition across all features." : "დაამატეთ თქვენი პროფილის ინფორმაცია! მიუთითეთ თქვენი სრული სახელი, რათა ადვილად იყოთ ამოცნობილი სხვადსახვა ფუნქციებში.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "დაამატეთ თქვენი პროფილის ინფორმაცია! დააყენეთ პროფილის ფოტო-სურათი, რათა ადვილად იყოთ ამოცნობილი სხვადასხვა ფუნქციებში.",
    "About" : "შესახებ",
    "Get the apps to sync your files" : "თქვენი ფაილების სინქრონიზაციისთვის მოიპოვეთ აპლიკაციები",
    "Desktop client" : "დესკტოპ-კლიენტი",
    "iOS app" : "iOS აპლიკაცია",
    "Connect your desktop apps to %s" : "დაუკავშირეთ თქვენი დესკტოპ აპლიკაციები %s-ს",
    "Connect your calendar" : "დააკავშირეთ თქვენი კალენდარი",
    "Connect your contacts" : "დააკავშირეთ თქვენი კონტაქტები",
    "Access files via WebDAV" : "დაუკავშირდით ფაილებს WebDAV–ით",
    "A safe home for all your data" : "უსაფრთხო სახლი მთელი თქვენი მონაცემებისათვის",
    "Server address" : "სერვერის მისამართი",
    "Copy link" : "ბმულის კოპირება",
    "Copy to clipboard" : "კოპირება ბუფერში"
},
"nplurals=2; plural=(n!=1);");
